# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'
%define _with_repolib 1

%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define repodir %{_javadir}/repository.jboss.com/hibernate-validator/%{version}.%{reltag}-brew
%define repodirlib %{repodir}/lib
%define repodirres %{repodir}/resources
%define repodirsrc %{repodir}/src

%define section free

%define reltag GA
%define hname hibernate-validator
%define namedversion %{version}.%{reltag}

Summary:        Relational persistence and query service
Name:           hibernate3-validator
Version:        3.1.0
Release:        1.5.4%{?dist}
Epoch:          0
License:        LGPL
URL:            http://www.hibernate.org/412.html
Group:          Database
Source0:        hibernate-validator-3.1.0-src.tar.gz
# svn export https://svn.jboss.org/repos/hibernate/validator/tags/3.1.0.GA/ hibernate-validator
# tar czf hibernate-validator-3.1.0-src.tar.gz hibernate-validator
Source1:	%{hname}-jdstyle.css
Source2:	%{hname}-component-info.xml

Patch0:         %{hname}-common-build_xml.patch
# Patch to remove dependencies in ivy config file so that it doesn't get the 
# dependencies from repositories on line, we'll use the jars from the rpms
# installed
Patch1:         %{hname}-ivy.xml.patch

BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  java-devel >= 1.5.0
BuildRequires:  ant >= 0:1.7.1
# The following goes into lib/build:
BuildRequires:  ant-junit
BuildRequires:  junit >= 3.8.2
# The following goes into jdbc:
BuildRequires:  hsqldb
# The following goes into ivy:
BuildRequires:  ivy
BuildRequires:  maven-ant-tasks
# slf4j/api goes into build/lib/core
# slf4j/log4j12 goes into build/lib/test
BuildRequires:  slf4j >= 0:1.5.6
# The following goes into build/lib/core:
BuildRequires:  hibernate3 >= 0:3.3.2
BuildRequires:  hibernate3-annotations >= 0:3.4.0
BuildRequires:  hibernate3-entitymanager >= 0:3.4.0
BuildRequires:  hibernate3-commons-annotations >= 3.1.0
BuildRequires:  dom4j >= 0:1.6.1
BuildRequires:  hibernate3-ejb-persistence-3.0-api >= 0:3.4.0

#The following goes into build/lib/test:
BuildRequires:  antlr >= 0:2.7.6
BuildRequires:  objectweb-asm >= 3.1
BuildRequires:  jakarta-commons-collections >= 0:3.1
BuildRequires:  javassist >= 0:3.9.0
BuildRequires:  jta_1_1_api
BuildRequires:  junit >= 3.8.2
BuildRequires:  log4j >= 1.2.14
BuildRequires:  maven-deploy-plugin

Requires:  java >= 0:1.5
# EAP only - The environment will need to provide a compatible hibernate
Requires:  hibernate3 >= 0:3.3.2
Requires:  hibernate3-commons-annotations >= 0:3.1.0
Requires:  hibernate3-annotations >= 0:3.4.0
Requires:  hibernate3-entitymanager >= 0:3.4.0
Requires:  hibernate3-ejb-persistence-3.0-api >= 0:1.0.2

BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Hibernate Validator aims at defining and checking a domain model level
constraints.
It supports custom constraints definitions as well as full internationalization.
Annotations are used to define constraints on object level.
The validation mechanism can be executed in different layers in your application
without having to duplicate any of these rules (presentation layer,
data access layer, Database schema).

Hibernate Requires Hibernate Core 3.2 and above.
This version runs well with Hibernate Annotations 3.4.x and Hibernate EntityManager 3.4.x

%if %{with_repolib}
%package	 repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	Development/Libraries/Java

%description	 repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio
%endif

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%prep
%setup -q -n %{hname}
# remove all binary libs
for j in $(find . -name "*.jar"); do
	mv $j $j.no
done
cp %{SOURCE1} doc/api/jdstyle.css

%patch0 -b .sav
%patch1 -b .sav

cp %{SOURCE2} .
sed -i 's/@VERSION@/%{version}.%{reltag}-brew/g' %{hname}-component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{hname}-component-info.xml

%build
export JAVA_HOME=/usr/lib/jvm/java-1.6.0

build-jar-repository -s -p lib/build \
ant/ant-junit \
junit

build-jar-repository -s -p jdbc hsqldb

build-jar-repository -s -p ivy \
	ivy \
	maven-ant-tasks


mkdir -p  build/lib/core
build-jar-repository -s -p build/lib/core \
slf4j/api \
dom4j \
hibernate3-core \
hibernate3-commons-annotations \
hibernate3-ejb-persistence-3.0-api \
hibernate3-annotations \
hibernate3-entitymanager

mkdir -p build/lib/test
build-jar-repository -s -p build/lib/test \
slf4j/log4j12 \
antlr \
objectweb-asm/asm \
commons-collections \
junit \
log4j \
jta_1_1_api \
javassist

ant \
	-Doffline.repository.jboss.org=$PWD/build \
	jar javadoc junit junitinstrument deploy

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p target/%{hname}/%{hname}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|%{name}|%{hname}|g"`; done)
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

## javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr target/%{hname}/doc/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
#(cd $RPM_BUILD_ROOT%{_javadocdir} && for doc in *-%{version}; do ln -sf ${doc} `echo $doc| sed "s|%{name}|%{hname}|g"`; done)
#(cd $RPM_BUILD_ROOT%{_javadocdir} && for doc in *-%{version}; do ln -sf ${doc} `echo $doc| sed "s|-%{version}||g"`; done)
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

# manual
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -p lgpl.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

#pom
%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%add_to_maven_depmap org.hibernate %{hname} %{namedversion} JPP %{name}
%{__install} -p -m 644 pom.xml %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom

%if %{with_repolib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodir}
	%{_bindir}/mvn-jpp deploy:deploy-file \
	-DgroupId=org.hibernate \
	-DartifactId=hibernate-validator \
	-Dversion=%{namedversion} \
	-Dpackaging=jar \
	-Dfile=%{buildroot}%{_javadir}/%{hname}.jar \
	-DpomFile=%{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom \
	-Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/ \
	-DrepositoryId=jboss-releases
    %{_bindir}/mvn-jpp deploy:deploy-file \
	-DgroupId=org.hibernate \
	-DartifactId=hibernate-validator \
	-Dversion=%{namedversion} \
	-Dpackaging=java-source \
    -DgeneratePom=false \
	-Dfile=build/src.jar \
	-Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/ \
	-DrepositoryId=jboss-releases
	install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
	install -m 755 %{hname}-component-info.xml $RPM_BUILD_ROOT%{repodir}/component-info.xml
	tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
	%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
	%{__sed} -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml	
	install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{PATCH1} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
	cp $RPM_BUILD_ROOT%{_javadir}/%{hname}.jar $RPM_BUILD_ROOT%{repodirlib}
	cp -p build/src.jar $RPM_BUILD_ROOT%{repodirlib}/%{hname}-sources.jar
	cp %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom $RPM_BUILD_ROOT%{repodirlib}/hibernate-validator.pom
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}
fi

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}/lgpl.txt
%{_javadir}*/*.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Wed Jan 05 2011 Hui Wang <huwang@redhat.com> - 0:3.1.0-1.5.4
- Add source jar to repolib

* Mon Dec 27 2010 Hui Wang <huwang@redhat.com> - 0:3.1.0-1.5.3
- Fix %%files for signed jars
- Add deploy command in repolib

* Fri May 21 2010 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.5.2
- Add compatible line

* Tue Apr 20 2010 Yiqiao Wang <yiwang@redhatc.om> - 0:3.1.0-1.5.1
- Rebuild 
- Change JAVA_HOME from java-1.5.0 java-1.6.0

* Fri Jan 29 2010 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.5
- Add pom to repolib

* Fri Jan 22 2010 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.4
-Update release tag to rebuild in brew

* Fri Jan 15 2010 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.3
- Add compatible line of core 3.3.2.GA_CP01, 3.3.2.GA_CP01-brew

* Mon Jul 20 2009 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.2
- Update copyrights to 2009
* Sun Jul 19 2009 Gail Badner <gbadner@redhat.com> - 0:3.1.0-1.1
- First release for RHEL-4-EP-5
